/**
 * Sonatype Nexus (TM) Open Source Version
 * Copyright (c) 2007-2012 Sonatype, Inc.
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/oss/attributions.
 *
 * This program and the accompanying materials are made available under the terms of the Eclipse Public License Version 1.0,
 * which accompanies this distribution and is available at http://www.eclipse.org/legal/epl-v10.html.
 *
 * Sonatype Nexus (TM) Professional Version is available from Sonatype, Inc. "Sonatype" and "Sonatype Nexus" are trademarks
 * of Sonatype, Inc. Apache Maven is a trademark of the Apache Software Foundation. M2eclipse is a trademark of the
 * Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
package org.sonatype.nexus.artifactorybridge;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;

import org.codehaus.plexus.util.IOUtil;
import org.restlet.data.MediaType;
import org.restlet.resource.OutputRepresentation;

public class URLInputStreamRepresentation
    extends OutputRepresentation
{

    private InputStream input;

    private HttpURLConnection urlConn;

    public URLInputStreamRepresentation( String type, InputStream input, HttpURLConnection urlConn )
    {
        super( MediaType.valueOf( type ) );
        if ( input == null )
        {
            throw new NullPointerException( "input" );
        }
        if ( urlConn == null )
        {
            throw new NullPointerException( "urlConn" );
        }
        this.input = input;
        this.urlConn = urlConn;
    }

    @Override
    public void write( OutputStream out )
        throws IOException
    {
        IOUtil.copy( input, out );
        out.flush();
    }

    @Override
    public void release()
    {
        IOUtil.close( input );
        urlConn.disconnect();

        input = null;
        urlConn = null;

        super.release();
    }
}
